# Iugu

The Iugu provides a Python REST APIs to create, process and manage payments.

## Installation

Clone the source:

    $ git clone git@github.com:iugu/iugu-python.git
    
Execute the setup script:

    $ cd iugu-python
    $ python setup.py install

## Documentation

Visit [iugu.com/referencias/api](http://iugu.com/referencias/api) for api reference or [iugu.com/documentacao](http://iugu.com/documentacao) for full documentation

## Author

Originally by [Felipe Tomaz](https://github.com/lspecian) and [Arthur Furlan](https://github.com/arthurfurlan).

## Contributor

[André Kiffer](https://github.com/andrekiffer).
[Rodolpho Pivetta Sabino](https://github.com/rodolphopivetta).
